@@ -38,7 +38,7 @@ PolicykitAgentGUI::PolicykitAgentGUI(const QString &actionId,
                                      const QString &iconName,
                                      const PolkitQt1::Details &details,
                                      const PolkitQt1::Identity::List &identities)
-   : QDialog(0, Qt::WindowStaysOnTopHint)
+   : QDialog(nullptr, Qt::WindowStaysOnTopHint)
 {
     setupUi(this);
     Q_UNUSED(actionId);
@@ -66,6 +66,8 @@ PolicykitAgentGUI::PolicykitAgentGUI(const QString &actionId,
     passwordEdit->setFocus(Qt::OtherFocusReason);
 }
 
+PolicykitAgentGUI::~PolicykitAgentGUI() = default;
+
 void PolicykitAgentGUI::setPrompt(const PolkitQt1::Identity &identity, const QString &text, bool echo)
 {
     const int ix = identityComboBox->findText(identity.toString());
